@@ -30,6 +30,8 @@ from smart import *
 import locale
 import stat
 import os
+from datetime import datetime
+import time
 
 try:
     import rpmhelper
@@ -84,6 +86,7 @@ class RPMHeaderPackageInfo(PackageInfo):
         PackageInfo.__init__(self, package, order)
         self._loader = loader
         self._path = None
+        self._change = None
 
     def getReferenceURLs(self):
         url = self._h[rpm.RPMTAG_URL]
@@ -103,6 +106,9 @@ class RPMHeaderPackageInfo(PackageInfo):
     def getMD5(self, url):
         return self._loader.getMD5(self)
 
+    def getBuildTime(self):
+        return self._h[rpm.RPMTAG_BUILDTIME]
+
     def getInstalledSize(self):
         return self._h[rpm.RPMTAG_SIZE]
 
@@ -126,6 +132,12 @@ class RPMHeaderPackageInfo(PackageInfo):
     def getSummary(self):
         return self._getHeaderString(rpm.RPMTAG_SUMMARY)
 
+    def getSource(self):
+        sourcerpm = self._getHeaderString(rpm.RPMTAG_SOURCERPM)
+        sourcerpm = sourcerpm.replace(".src", "")
+        sourcerpm = sourcerpm.replace(".nosrc", "")
+        return sourcerpm.replace(".rpm", "")
+    
     def getGroup(self):
         s = self._loader.getGroup(self._package)
         for encoding in ENCODINGS:
@@ -138,6 +150,27 @@ class RPMHeaderPackageInfo(PackageInfo):
             s = ""
         return s
 
+    def getLicense(self):
+        return self._getHeaderString(rpm.RPMTAG_LICENSE)
+
+    def getChangeLog(self):
+        if self._change is None:
+            logname = self._h[rpm.RPMTAG_CHANGELOGNAME]
+            logtime = self._h[rpm.RPMTAG_CHANGELOGTIME]
+            change = self._h[rpm.RPMTAG_CHANGELOGTEXT]
+            if type(logname) != list:
+                logname = [logname]
+            if type(logtime) != list:
+                logtime = [logtime]              
+            if type(change) != list:
+                change = [change]
+            self._change = {}
+            if len(logtime) > 0:
+                for i in range(len(change)):
+                    self._change[2*i] = datetime.fromtimestamp(logtime[i]).strftime("%Y-%m-%d")+"  "+ logname[i]
+                    self._change[2*i+1] = "  " + change[i]
+        return self._change
+
     def getPathList(self):
         if self._path is None:
             paths = get_header_filenames(self._h)
