@@ -58,6 +58,9 @@ class RPMMetaDataPackageInfo(PackageInfo):
             return [posixpath.join(self._loader._baseurl, url)]
         return []
 
+    def getBuildTime(self):
+        return self._info.get("build_time")
+
     def getInstalledSize(self):
         return self._info.get("installed_size")
 
@@ -70,6 +73,9 @@ class RPMMetaDataPackageInfo(PackageInfo):
     def getSHA(self, url):
         return self._info.get("sha")
 
+    def getSHA256(self, url):
+        return self._info.get("sha256")
+
     def getDescription(self):
         return self._info.get("description", "")
 
@@ -79,9 +85,18 @@ class RPMMetaDataPackageInfo(PackageInfo):
     def getReferenceURLs(self):
         return [self._info.get("url", "")]
 
+    def getSource(self):
+        sourcerpm = self._info.get("sourcerpm", "")
+        sourcerpm = sourcerpm.replace(".src", "")
+        sourcerpm = sourcerpm.replace(".nosrc", "")
+        return sourcerpm.replace(".rpm", "")
+    
     def getGroup(self):
         return self._info.get("group", "")
 
+    def getLicense(self):
+        return self._info.get("license", "")
+
 
 class RPMMetaDataLoader(Loader):
 
@@ -117,12 +132,15 @@ class RPMMetaDataLoader(Loader):
         SUMMARY     = nstag(NS_COMMON, "summary")
         DESCRIPTION = nstag(NS_COMMON, "description")
         URL         = nstag(NS_COMMON, "url")
+        TIME        = nstag(NS_COMMON, "time")
         SIZE        = nstag(NS_COMMON, "size")
         LOCATION    = nstag(NS_COMMON, "location")
         FORMAT      = nstag(NS_COMMON, "format")
         CHECKSUM    = nstag(NS_COMMON, "checksum")
         FILE        = nstag(NS_COMMON, "file")
+        SOURCERPM   = nstag(NS_RPM, "sourcerpm")
         GROUP       = nstag(NS_RPM, "group")
+        LICENSE     = nstag(NS_RPM, "license")
         ENTRY       = nstag(NS_RPM, "entry")
         REQUIRES    = nstag(NS_RPM, "requires")
         PROVIDES    = nstag(NS_RPM, "provides")
@@ -201,6 +219,10 @@ class RPMMetaDataLoader(Loader):
                     if elem.text:
                         info["url"] = elem.text
 
+                elif tag == TIME:
+                    info["time"] = int(elem.get("file"))
+                    info["build_time"] = int(elem.get("build"))
+
                 elif tag == SIZE:
                     info["size"] = int(elem.get("package"))
                     info["installed_size"] = int(elem.get("installed"))
@@ -213,10 +235,18 @@ class RPMMetaDataLoader(Loader):
                 elif tag == LOCATION:
                     info["location"] = elem.get("href")
 
+                elif tag == SOURCERPM:
+                    if elem.text:
+                        info["sourcerpm"] = elem.text
+
                 elif tag == GROUP:
                     if elem.text:
                         info["group"] = elem.text
 
+                elif tag == LICENSE:
+                    if elem.text:
+                        info["license"] = elem.text
+
                 elif tag == FILE:
                     filedict[elem.text] = True
 
@@ -261,7 +291,7 @@ class RPMMetaDataLoader(Loader):
                                 Prv = RPMNameProvides
                             else:
                                 Prv = RPMProvides
-                            prvdict[(Prv, ename, eversion)] = True
+                            prvdict[(Prv, ename.encode('utf-8'), eversion)] = True
 
                     elif lasttag == OBSOLETES:
                         tup = (RPMObsoletes, ename, erelation, eversion)
