@@ -143,12 +143,21 @@ class PackageInfo(object):
     def getSummary(self):
         return ""
 
+    def getSource(self):
+        return ""
+
     def getGroup(self):
         return ""
 
+    def getLicense(self):
+        return ""
+
     def getPathList(self):
         return []
 
+    def getChangeLog(self):
+        return []
+
     def pathIsDir(self, path):
         return None
 
@@ -161,6 +170,9 @@ class PackageInfo(object):
     def pathIsSpecial(self, path):
         return None
 
+    def getBuildTime(self):
+        return None
+
     def getInstalledSize(self):
         return None
 
@@ -179,6 +191,9 @@ class PackageInfo(object):
     def getSHA(self, url):
         return None
 
+    def getSHA256(self, url):
+        return None
+
     def validate(self, url, localpath, withreason=False):
         try:
             if not os.path.isfile(localpath):
@@ -208,6 +223,22 @@ class PackageInfo(object):
                     raise Error, _("Invalid MD5 (expected %s, got %s)") % \
                                  (filemd5, lfilemd5)
             else:
+                filesha256 = self.getSHA256(url)
+                if filesha256:
+                    try:
+                        from hashlib import sha256
+                        digest = sha256()
+                        file = open(localpath)
+                        data = file.read(BLOCKSIZE)
+                        while data:
+                            digest.update(data)
+                            data = file.read(BLOCKSIZE)
+                        lfilesha256 = digest.hexdigest()
+                        if lfilesha256 != filesha256:
+                           raise Error, _("Invalid SHA256 (expected %s, got %s)") % \
+                                         (filesha256, lfilesha256)
+                    except ImportError:
+                        pass
                 filesha = self.getSHA(url)
                 if filesha:
                     try:
