@@ -54,6 +54,8 @@ def parse_options(argv):
                       help=_("split operation in steps"))
     parser.add_option("--urls", action="store_true",
                       help=_("dump needed urls and don't commit operation"))
+    parser.add_option("--metalink", action="store_true",
+                      help=_("dump metalink xml and don't commit operation"))
     parser.add_option("--download", action="store_true",
                       help=_("download packages and don't commit operation"))
     parser.add_option("--explain", action="store_true",
@@ -76,7 +78,7 @@ def main(ctrl, opts):
     urls = []
     for arg in opts.args[:]:
         if (os.path.isfile(arg) and
-            '/' in arg or filter(None, hooks.call("check-package-file", arg))):
+            '/' in arg or ctrl.checkPackageFile(arg)):
             ctrl.addFileChannel(arg)
             opts.args.remove(arg)
         elif ":/" in arg:
@@ -91,7 +93,12 @@ def main(ctrl, opts):
         for url, file in succ.items():
             ctrl.addFileChannel(file)
             opts.args.remove(url)
-    ctrl.reloadChannels()
+    if sysconf.get("auto-update"):
+        from smart.commands import update
+        updateopts = update.parse_options([])
+        update.main(ctrl, updateopts)
+    else:
+        ctrl.reloadChannels()
     cache = ctrl.getCache()
     trans = Transaction(cache, PolicyInstall)
     for channel in ctrl.getFileChannels():
@@ -168,6 +175,8 @@ def main(ctrl, opts):
         confirm = not opts.yes
         if opts.urls:
             ctrl.dumpTransactionURLs(trans)
+        elif opts.metalink:
+            ctrl.dumpTransactionMetalink(trans)
         elif opts.dump:
             ctrl.dumpTransactionPackages(trans, install=True)
         elif opts.download:
