@@ -23,12 +23,15 @@ import cPickle
 import sys, os
 import copy
 import time
+import tempfile
+import tarfile
 
 from smart.transaction import ChangeSet, ChangeSetSplitter, INSTALL, REMOVE
 from smart.util.filetools import compareFiles, setCloseOnExecAll
 from smart.util.objdigest import getObjectDigest
 from smart.util.pathlocks import PathLocks
 from smart.util.strtools import strToBool
+from smart.util.metalink import Metalink, Metafile
 from smart.searcher import Searcher
 from smart.media import MediaSet
 from smart.progress import Progress
@@ -78,6 +81,14 @@ class Control(object):
         return [x for x in self._channels.values()
                 if isinstance(x, FileChannel)]
 
+    def checkPackageFile(self, arg):
+        if os.path.exists(arg):
+            if filter(None, hooks.call("check-package-file", arg)):
+                return True
+            if tarfile.is_tarfile(arg) and os.path.getsize(arg) > 0:
+                return True
+        return False
+
     def addFileChannel(self, filename):
         if not self._sysconfchannels:
             # Give a chance for backends to register
@@ -91,6 +102,23 @@ class Control(object):
                                  % channel.getAlias()
                 self._channels[channel.getAlias()] = channel
                 found = True
+        if not found and tarfile.is_tarfile(filename):
+            tempdir = tempfile.mkdtemp()
+            iface.debug("Extracting from %s to %s" % (filename, tempdir))
+            tarball = tarfile.open(filename, 'r')
+            names = tarball.getnames()
+            for name in names:
+                tarball.extract(name, path=tempdir)
+            tarball.close()
+            files = os.listdir(tempdir)
+            for file in files:
+                path = os.path.join(tempdir, file)
+                if os.path.isdir(path) and file == "RPMS":
+                    for rpm in os.listdir(path):
+                        files.append(os.path.join(path, rpm))
+                if os.path.isfile(path) and self.checkPackageFile(path):
+                    self.addFileChannel(path)
+                    found = True
         if not found:
             raise Error, _("Unable to create channel for file: %s") % filename
 
@@ -422,6 +450,41 @@ class Control(object):
         for url in urls:
             print >>output, url
 
+    def dumpTransactionMetalink(self, trans, output=None):
+        changeset = trans.getChangeSet()
+        self.dumpMetalink([x for x in changeset if changeset[x] is INSTALL])
+
+    def dumpMetalink(self, packages, output=None):
+        if output is None:
+            output = sys.stderr
+        metalink = Metalink()
+        msys = self._fetcher.getMirrorSystem()
+        for pkg in packages:
+            loaders = [x for x in pkg.loaders if not x.getInstalled()]
+            if not loaders:
+                raise Error, _("Package %s is not available for downloading") \
+                             % pkg
+            info = loaders[0].getInfo(pkg)
+            if not info.getURLs():
+                raise Error, _("Package %s is not available for downloading") \
+                             % pkg
+            for url in info.getURLs():
+                metafile = Metafile(pkg.name, pkg.version, info.getSummary())
+                mirror = msys.get(url)
+                mirrorurls = []
+                mirrorurl = mirror.getNext()
+                while mirrorurl:
+                    mirrorurls.append(mirrorurl)
+                    mirrorurl = mirror.getNext()
+                metafile.append(mirrorurls,
+                                size=info.getSize(url),
+                                md5=info.getMD5(url),
+                                sha=info.getSHA(url),
+                                sha256=info.getSHA256(url))
+                metalink.append(metafile)
+        if packages:
+            metalink.write(output)
+
     def dumpTransactionPackages(self, trans, install=False, remove=False,
                                 output=None):
         if output is None:
@@ -456,6 +519,26 @@ class Control(object):
         fetcher.run(what=what)
         return fetcher.getSucceededSet(), fetcher.getFailedSet()
 
+    def downloadMetalink(self, metalink, what=None, caching=NEVER, targetdir=None):
+        fetcher = self._fetcher
+        fetcher.reset()
+        self.reloadMirrors()
+        if targetdir is None:
+            localdir = os.path.join(sysconf.get("data-dir"), "tmp/")
+            if not os.path.isdir(localdir):
+                os.makedirs(localdir)
+            fetcher.setLocalDir(localdir, mangle=True)
+        else:
+            fetcher.setLocalDir(targetdir, mangle=False)
+        fetcher.setCaching(caching)
+        for metafile in Metalink.parse(open(metalink)).files():
+            urls = metafile.urls()
+            info = metafile.info()
+            # TODO: use random url
+            fetcher.enqueue(urls[0], **info)
+        fetcher.run(what=what)
+        return fetcher.getSucceededSet(), fetcher.getFailedSet()
+
     def downloadTransaction(self, trans, caching=OPTIONAL, confirm=True):
         return self.downloadChangeSet(trans.getChangeSet(), caching,
                                       confirm=confirm)
@@ -484,6 +567,52 @@ class Control(object):
             if fetched == len(packages):
                 break
         return True
+ 
+    def packPackages(self, packages, targetdir=None, outputname=None):
+        channels = getChannelsWithPackages(packages)
+        fetched = 0
+        pkgpaths = {}
+        while True:
+            self._achanset.setChannels(channels)
+            fetchpkgs = []
+            for channel in channels:
+                if self._achanset.isAvailable(channel):
+                    fetchpkgs.extend(channels[channel])
+            pkgpaths.update(self.fetchPackages(fetchpkgs, OPTIONAL, targetdir))
+            fetched += len(fetchpkgs)
+            if fetched == len(packages):
+                break
+        files = []
+        for pkg in pkgpaths:
+            files.append(pkgpaths[pkg][0])
+        self.packFiles(files, targetdir, outputname)
+
+    def packFiles(self, files, targetdir=None, outputname=None):
+        prog = iface.getProgress(self, True)
+        prog.start()
+        prog.setTopic(_("Creating pack..."))
+        if outputname:
+            filename = outputname
+        else:
+            filename = "pack.tar"
+        if not filename.startswith("/"):
+            filename = os.path.join(targetdir, filename)
+        tarball = tarfile.open(filename, 'w')
+        total = len(files)
+        current = 1
+        for file in files:
+            prog.set(current, total)
+            prog.setSubTopic(file, os.path.basename(file))
+            prog.setSub(file, 0, 1)
+            prog.show()
+            tarball.add(file, os.path.basename(file), False)
+            prog.setSubDone(file)
+            prog.show()
+            current += 1
+        tarball.close()
+        prog.setDone()
+        prog.show()
+        prog.stop()
 
     def writeCommitLog(self, changeset):
         """ writes the operations performed in the current changeset
@@ -659,6 +788,7 @@ class Control(object):
                 pkgitems[pkg].append(fetcher.enqueue(url, media=media,
                                                      md5=info.getMD5(url),
                                                      sha=info.getSHA(url),
+                                                     sha256=info.getSHA256(url),
                                                      size=info.getSize(url),
                                                      validate=info.validate))
         if targetdir:
