@@ -75,6 +75,7 @@ UI = """
         <menuitem action="hide-installed"/>
         <menuitem action="hide-uninstalled"/>
         <menuitem action="hide-unmarked"/>
+        <menuitem action="hide-unlocked"/>
         <menuitem action="hide-old"/>
         <separator/>
         <menuitem action="expand-all"/>
@@ -113,7 +114,7 @@ UI = """
 ACTIONS = [
     ("file", None, _("_File")),
     ("update-selected-channels", "gtk-refresh", _("Update _Selected Channels..."), None,
-     _("Update given channels"), "self.updateChannels(True)"),
+     _("Update given channels"), "self.updateSelected()"),
     ("update-channels", "gtk-refresh", _("_Update Channels"), None,
      _("Update channels"), "self.updateChannels()"),
     ("rebuild-cache", None, _("_Rebuild Cache"), None,
@@ -154,13 +155,13 @@ ACTIONS = [
     ("view", None, _("_View")),
     ("tree-style", None, _("_Tree Style")),
     ("expand-all", "gtk-open", _("_Expand All"), None,
-     _("Expand all items in the tree"), "self._pv.getTreeView().expand_all()"),
+     _("Expand all items in the tree"), "self.expandPackages()"),
     ("collapse-all", "gtk-close", _("_Collapse All"), None,
-     _("Collapse all items in the tree"), "self._pv.getTreeView().collapse_all()"),
+     _("Collapse all items in the tree"), "self.collapsePackages()"),
     ("summary-window", None, _("_Summary Window"), "<control>s",
      _("Show summary window"), "self.showChanges()"),
     ("log-window", None, _("_Log Window"), None,
-     _("Show log window"), "self._log.show()"),
+     _("Show log window"), "self.showLog()"),
 
     ("help", None, _("_Help")),
     ("about", None, _("_About"), None,
@@ -221,6 +222,7 @@ class GtkInteractiveInterface(GtkInterface):
                             ("hide-installed", _("Hide Installed")),
                             ("hide-uninstalled", _("Hide Uninstalled")),
                             ("hide-unmarked", _("Hide Unmarked")),
+                            ("hide-unlocked", _("Hide Unlocked")),
                             ("hide-old", _("Hide Old"))]:
             action = gtk.ToggleAction(name, label, "", "")
             action.connect("toggled", lambda x, y: self.toggleFilter(y), name)
@@ -400,6 +402,9 @@ class GtkInteractiveInterface(GtkInterface):
     def getChangeSet(self):
         return self._changeset
 
+    def updateSelected(self):
+        self.updateChannels(selected=True)
+
     def updateChannels(self, selected=False, channels=None):
         if selected:
             aliases = GtkChannelSelector().show()
@@ -440,6 +445,15 @@ class GtkInteractiveInterface(GtkInterface):
     def showChanges(self):
         return self._changes.showChangeSet(self._changeset)
 
+    def showLog(self):
+        return self._log.show()
+
+    def expandPackages(self):
+        self._pv.getTreeView().expand_all()
+
+    def collapsePackages(self):
+        self._pv.getTreeView().collapse_all()
+
     def toggleFilter(self, filter):
         if filter in self._filters:
             del self._filters[filter]
@@ -508,6 +522,30 @@ class GtkInteractiveInterface(GtkInterface):
             self._changeset.setState(changeset)
             self.changedMarks()
 
+    def lockPackages(self, pkgs, lock):
+        if not lock:
+             for pkg in pkgs:
+                  pkgconf.clearFlag("lock", pkg.name, "=", pkg.version)
+             self._pv.queue_draw()
+             self._pi.setPackage(pkgs[0])
+        else:
+             for pkg in pkgs:
+                  pkgconf.setFlag("lock", pkg.name, "=", pkg.version)
+             self._pv.queue_draw()
+             self._pi.setPackage(pkgs[0])
+
+    def lockAllPackages(self, pkgs, lock):
+        if not lock:
+             for pkg in pkgs:
+                  pkgconf.clearFlag("lock", pkg.name)
+             self._pv.queue_draw()
+             self._pi.setPackage(pkgs[0])
+        else:
+             for pkg in pkgs:
+                  pkgconf.setFlag("lock", pkg.name)
+             self._pv.queue_draw()
+             self._pi.setPackage(pkgs[0])
+
     def packagePopup(self, packageview, pkgs, event):
 
         menu = gtk.Menu()
@@ -596,10 +634,7 @@ class GtkInteractiveInterface(GtkInterface):
             else:
                 image.set_from_pixbuf(getPixbuf("package-available"))
             def unlock_this(x):
-                for pkg in pkgs:
-                    pkgconf.clearFlag("lock", pkg.name, "=", pkg.version)
-                self._pv.queue_draw()
-                self._pi.setPackage(pkgs[0])
+                self.lockPackages(pkgs, False)
             item.connect("activate", unlock_this)
         else:
             item = gtk.ImageMenuItem(_("Lock this version"))
@@ -608,10 +643,7 @@ class GtkInteractiveInterface(GtkInterface):
             else:
                 image.set_from_pixbuf(getPixbuf("package-available-locked"))
             def lock_this(x):
-                for pkg in pkgs:
-                    pkgconf.setFlag("lock", pkg.name, "=", pkg.version)
-                self._pv.queue_draw()
-                self._pi.setPackage(pkgs[0])
+                self.lockPackages(pkgs, True)
             item.connect("activate", lock_this)
         item.set_image(image)
         if inconsistent:
@@ -626,10 +658,7 @@ class GtkInteractiveInterface(GtkInterface):
             else:
                 image.set_from_pixbuf(getPixbuf("package-available"))
             def unlock_all(x):
-                for pkg in pkgs:
-                    pkgconf.clearFlag("lock", pkg.name)
-                self._pv.queue_draw()
-                self._pi.setPackage(pkgs[0])
+                self.lockAllPackages(pkgs, False)
             item.connect("activate", unlock_all)
         else:
             item = gtk.ImageMenuItem(_("Lock all versions"))
@@ -638,10 +667,7 @@ class GtkInteractiveInterface(GtkInterface):
             else:
                 image.set_from_pixbuf(getPixbuf("package-available-locked"))
             def lock_all(x):
-                for pkg in pkgs:
-                    pkgconf.setFlag("lock", pkg.name)
-                self._pv.queue_draw()
-                self._pi.setPackage(pkgs[0])
+                self.lockAllPackages(pkgs, True)
             item.connect("activate", lock_all)
         item.set_image(image)
         if inconsistent:
@@ -810,6 +836,8 @@ class GtkInteractiveInterface(GtkInterface):
                 packages = [x for x in packages if x in changeset]
             if "hide-installed" in filters:
                 packages = [x for x in packages if not x.installed]
+            if "hide-unlocked" in filters:
+                packages = pkgconf.filterByFlag("lock", packages)
             if "hide-old" in filters:
                 packages = pkgconf.filterByFlag("new", packages)
 
